imblearn.over_sampling.RandomOverSampler
========================================

.. currentmodule:: imblearn.over_sampling

.. autoclass:: RandomOverSampler

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RandomOverSampler.__init__
      ~RandomOverSampler.fit
      ~RandomOverSampler.fit_sample
      ~RandomOverSampler.get_params
      ~RandomOverSampler.sample
      ~RandomOverSampler.set_params
   
   

   
   
   